@@ -100,7 +100,8 @@ class Sequential:
 
     # epoch
     if batch_size is None:
-      steps = x_train.shape[0]
+      batch_size = x_train.shape[0]
+      steps = 1
     else:
       steps = int(x_train.shape[0]//batch_size)
 
