@@ -36,7 +36,7 @@ class GD:
 
     # Zs.append(Z_new) # 마지막 출력을 쓴다.
     if len(Z_new) == 1:
-      Z_new.reshape(-1,1)
+      Z_new = Z_new.reshape(-1,1)
 
     return Z_new, Ys, Zs
   
